0.9.9 API documentation: vector_double1_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_double1_precision.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 #include "../detail/type_vec1.hpp"
16
17 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
18 # pragma message("GLM: GLM_EXT_vector_double1_precision extension included")
19 #endif
20
21 namespace glm
22 {
25
27 typedef vec<1, double, highp> highp_dvec1;
28
30 typedef vec<1, double, mediump> mediump_dvec1;
31
33 typedef vec<1, double, lowp> lowp_dvec1;
34
36 }//namespace glm
glm::lowp_dvec1
vec< 1, double, lowp > lowp_dvec1
1 component vector of double-precision floating-point numbers using low precision arithmetic in term ...
Definition: vector_double1_precision.hpp:33
glm::highp_dvec1
vec< 1, double, highp > highp_dvec1
1 component vector of double-precision floating-point numbers using high precision arithmetic in term...
Definition: vector_double1_precision.hpp:27
glm::mediump_dvec1
vec< 1, double, mediump > mediump_dvec1
1 component vector of double-precision floating-point numbers using medium precision arithmetic in te...
Definition: vector_double1_precision.hpp:30
glm
Definition: common.hpp:20